src/hotspot/share/runtime/safepoint.cpp
changeset 52628 639a3e43f5b7
parent 52460 f1bb77833b59
child 52672 bbfa1b3aaf7e
--- a/src/hotspot/share/runtime/safepoint.cpp	Tue Nov 20 22:37:34 2018 +0100
+++ b/src/hotspot/share/runtime/safepoint.cpp	Tue Nov 20 22:59:27 2018 +0100
@@ -978,9 +978,9 @@
     }
   }
 
   // To debug the long safepoint, specify both DieOnSafepointTimeout &
   // ShowMessageBoxOnError.
-  if (DieOnSafepointTimeout) {
+  if (AbortVMOnSafepointTimeout) {
     fatal("Safepoint sync time longer than " INTX_FORMAT "ms detected when executing %s.",
           SafepointTimeoutDelay, VMThread::vm_safepoint_description());
   }
@@ -978,9 +978,9 @@
   }
 
-  // To debug the long safepoint, specify both DieOnSafepointTimeout &
+  // To debug the long safepoint, specify both AbortVMOnSafepointTimeout &
   // ShowMessageBoxOnError.